ClassManager class

Implemented types
Mixed-in types

Constructors

ClassManager({required String filePath, required String identifier})

Properties

className ↔ String?
getter/setter pairoverride-getter
dataSingleton → ClassManagerResultData
no setteroverride
filePath → String
final
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
final
parsedFileContent → String
no setterinherited
parsedFileUnit → CompilationUnit
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

lastConstFactoryLineNumber() → ClassManagerResultData
override
lastLineNumberGet() → ClassManagerResultData
override
listAllConstructors() → ClassManagerResultData
override
listAllGetters() → ClassManagerResultData
override
listAllMethods() → ClassManagerResultData
override
listAllSetters() → ClassManagerResultData
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parsedFile() → ParseStringResult
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited