ConstructorManagerResultData class

Inheritance

Constructors

ConstructorManagerResultData()
factory

Properties

filePath String?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
identifier String?
getter/setter pairinherited
identifierFormat String?
getter/setter pairinherited
manager String?
getter/setter pairinherited
otherProps Map<String, dynamic>
getter/setter pairinherited
parsedIdentifier String?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
succeedTasks Set<String>
getter/setter pairinherited

Methods

addTaskResultValue(dynamic value, [Map<String, dynamic>? others]) → void
inherited
addTaskResultValueTaskName([List<String>? subTasks]) String
inherited
expose({LogMethods? method = .removeEmptyThenPrettyPrint}) → void
inherited
exposeJSON(JSONString jsonString, {LogMethods? method = .prettyPrint}) String
inherited
fullTaskNameAtFrame([List<String>? subTasks]) String
inherited
getClassAndMethodName(String input) String?
inherited
getLineNumberOfMain(String input) int?
inherited
mergeMaps(Map<String, dynamic> original, Map<String, dynamic> newData) Map<String, dynamic>
inherited
mergeTaskResultValue(Map<String, dynamic>? others) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prettyPrint(JSONString jsonValue) JSONString
inherited
removeEmpty(JSONString json) JSONString
inherited
toJSON() JSONString
inherited
toJson() Map<String, dynamic>
toString({LogMethods? method = .removeEmptyThenPrettyPrint}) JSONString
A string representation of this object.
inherited
update({String? identifier, String? fullIdentifier, String? identifierFormat, String? filePath, String? manager}) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

singleton ConstructorManagerResultData
final