ParseStringResultMixin mixin
- Mixin applications
Properties
- filePath → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- parsedFileContent → String
-
no setter
- parsedFileUnit → CompilationUnit
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parsedFile(
) → ParseStringResult -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited