JSONStringMixin mixin

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exposeJSON(JSONString jsonString, {LogMethods? method = .prettyPrint}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prettyPrint(JSONString jsonValue) JSONString
removeEmpty(JSONString json) JSONString
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited