replaceMethodInvocationArgs library

Functions

replaceMethodInvocationArgs(String filePath, String methodName, String newArgsSource) → String?
Surgically replaces the argument list of the first invocation of methodName in filePath. Returns the new file content if found and replaced, or null otherwise.