ConstructorManager class
- Implemented types
- Mixed-in types
Constructors
- ConstructorManager({required String filePath, required String identifier})
Properties
- className ↔ String?
-
getter/setter pair
- constructorName ↔ String?
-
getter/setter pair
- dataSingleton → ConstructorManagerResultData
-
no setter
- filePath → String
-
final
- fullIdentifier ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
final
- parsedFileContent → String
-
no setterinherited
- parsedFileUnit → CompilationUnit
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
findOrReplace(
{String? replacementText}) → ConstructorManagerResultData -
override
-
hasFactoryConstructor(
) → bool -
override
-
listAllConstructors(
) → ConstructorManagerResultData -
override
-
listAllConstructorsIgnoreIdentifier(
) → ConstructorManagerResultData -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parsedFile(
) → ParseStringResult -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited