MethodManager class
- Implemented types
- Mixed-in types
Constructors
- MethodManager({required String filePath, required String identifier})
Properties
- className ↔ String?
-
getter/setter pair
- dataSingleton → MethodManagerResultData
-
no setter
- filePath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
final
- methodName ↔ String?
-
getter/setter pair
- parsedFileContent → String
-
no setterinherited
- parsedFileUnit → CompilationUnit
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
info(
) → MethodManagerResultData -
override
-
listAllMethods(
) → MethodManagerResultData -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
ON_invocationFindByMethodName(
{String? replacementHandlerBody}) → MethodManagerResultData -
override
-
ON_invocationLastLineNumber(
) → MethodManagerResultData -
override
-
ON_invocationListAllMethods(
) → MethodManagerResultData -
override
-
paramsList(
) → MethodManagerResultData -
override
-
parsedFile(
) → ParseStringResult -
inherited
-
returnInnerPropType(
String propName, [int innerLevel = 1]) → MethodManagerResultData -
override
-
returnInnerType(
[int innerLevel = 1]) → MethodManagerResultData -
override
-
returnInnerTypeOfHttpResponse(
{String propName = "body", String? libraryUri = "package:http/src/response.dart", String? libraryClassName = "Response", int innerLevel = 1}) → Future< MethodManagerResultData> -
override
-
returnType(
) → MethodManagerResultData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited