ManagersResultData class

Mixed-in types
Implementers

Constructors

ManagersResultData({String? identifier, String? parsedIdentifier, String? identifierFormat, String? filePath, String? manager})

Properties

filePath String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
identifier String?
getter/setter pair
identifierFormat String?
getter/setter pair
manager String?
getter/setter pair
otherProps Map<String, dynamic>
getter/setter pair
parsedIdentifier String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
succeedTasks Set<String>
getter/setter pair

Methods

addTaskResultValue(dynamic value, [Map<String, dynamic>? others]) → void
addTaskResultValueTaskName([List<String>? subTasks]) String
expose({LogMethods? method = .removeEmptyThenPrettyPrint}) → void
exposeJSON(JSONString jsonString, {LogMethods? method = .prettyPrint}) String
inherited
fullTaskNameAtFrame([List<String>? subTasks]) String
getClassAndMethodName(String input) String?
getLineNumberOfMain(String input) int?
mergeMaps(Map<String, dynamic> original, Map<String, dynamic> newData) Map<String, dynamic>
mergeTaskResultValue(Map<String, dynamic>? others) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prettyPrint(JSONString jsonValue) JSONString
inherited
removeEmpty(JSONString json) JSONString
inherited
toJSON() JSONString
toString({LogMethods? method = .removeEmptyThenPrettyPrint}) JSONString
A string representation of this object.
override
update({String? identifier, String? fullIdentifier, String? identifierFormat, String? filePath, String? manager}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited