IClassManager class abstract

Implementers

Constructors

IClassManager()

Properties

className String?
no setter
dataSingleton ClassManagerResultData
no setter
filePath String
no setter
hashCode int
The hash code for this object.
no setterinherited
identifier String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

lastConstFactoryLineNumber() ClassManagerResultData
lastLineNumberGet() ClassManagerResultData
listAllConstructors() ClassManagerResultData
listAllGetters() ClassManagerResultData
listAllMethods() ClassManagerResultData
listAllSetters() ClassManagerResultData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

identifierFormat → const String