IMethodManager class abstract
- Implementers
Constructors
Properties
- filePath → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
info(
) → MethodManagerResultData -
listAllMethods(
) → MethodManagerResultData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
ON_invocationFindByMethodName(
{String? replacementHandlerBody}) → MethodManagerResultData -
ON_invocationLastLineNumber(
) → MethodManagerResultData -
ON_invocationListAllMethods(
) → MethodManagerResultData -
paramsList(
) → MethodManagerResultData -
returnInnerPropType(
String propName, [int innerLevel = 1]) → MethodManagerResultData -
returnInnerType(
[int innerLevel = 1]) → MethodManagerResultData -
returnInnerTypeOfHttpResponse(
{String propName = "body", String? libraryUri = "package:http/src/response.dart", String? libraryClassName = "Response", int innerLevel = 1}) → Future< MethodManagerResultData> -
returnType(
) → MethodManagerResultData -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- identifierFormat → const String