JSONStringResult class final

Mixed-in types

Constructors

JSONStringResult({required dynamic data, Map<String, dynamic>? meta})
JSONStringResult.parse(dynamic value)
factory

Properties

data ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
meta Map<String, dynamic>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dataAsList<T>() List<T>?
dataAsMap() Map<String, dynamic>?
expose({LogMethods? method = .prettyPrint}) JSONString
exposeJSON(JSONString jsonString, {LogMethods? method = .prettyPrint}) String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prettyPrint(JSONString jsonValue) JSONString
inherited
removeEmpty(JSONString json) JSONString
inherited
toJSONString() JSONString
toString({LogMethods? method}) JSONString
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited