BlocOnMethodFoundElement class
Constructors
Properties
- eventType → String
-
final
- foundNode → String
-
final
- handlerBody → String?
-
final
- handlerParameters → String?
-
final
- handlerReturnType → String?
-
final
- handlerSource → String?
-
final
- handlerSourceNode → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAsync → bool
-
final
- isGenerator → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited