ProtoMethod class

Constructors

ProtoMethod({required String name, required String requestType, required String responseType, bool isClientStreaming = false, bool isServerStreaming = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
isClientStreaming bool
final
isServerStreaming bool
final
name String
final
requestType String
final
responseType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited